@@ -32,7 +32,7 @@ namespace
 
 //SignalProxy_Progress:
 
-//This Signal Proxy allows the C++ coder to specify a SigC::Slot instead of a static function.
+//This Signal Proxy allows the C++ coder to specify a sigc::slot instead of a static function.
 class SignalProxy_Progress
 {
 public:
@@ -59,7 +59,7 @@ gint SignalProxy_Progress::c_callback(GnomeVFSXferProgressInfo* info, gpointer d
 {
   SignalProxy_Progress *const self = static_cast<SignalProxy_Progress*>(data);
   Gnome::Vfs::Transfer::ProgressInfo progInfo(info);
-  gint result = FALSE; //TODO: Use TRUE or FALSE instead?
+  gint result = FALSE;
   try
   {
     result = (self->slot_)(progInfo);
@@ -83,7 +83,7 @@ void transfer_list(const Glib::StringArrayHandle& source_uri_list, const Glib::S
       OverwriteMode overwrite_mode,
       const SlotProgress& slot)
 {
-  typedef std::list< Glib::RefPtr<Uri> > uri_list;
+  typedef std::list< Glib::RefPtr<const Uri> > uri_list;
   uri_list sources, targets;
 
   //Build lists of RefPtr<Uri>s from the strings:
@@ -97,6 +97,9 @@ void transfer_list(const Glib::StringArrayHandle& source_uri_list, const Glib::S
       iter_target++;
     }
   }
+
+  ListHandleUris temp = sources;
+  ListHandleUris temp2 = targets;
             
   transfer_list_uris(sources, targets, options, error_mode, overwrite_mode, slot);
 }
